==> clims-0.4.4-py3-none-any.whl: test/test_phonons.py <==
from click.testing import CliRunner
from ase.io import write, read
from ase.build import bulk
from test.file_comparison import compare_geo_files, compare_data_files
from clims.cli.phonons import clims_initialize_phonopy, clims_post_process_phonopy

Si_unit_cell = bulk("Si", crystalstructure="diamond", a=5.43)


def test_phonopy():
    runner = CliRunner()
    with open("test/phonons/aims.out") as fd:
        aims_out = fd.read()
    with runner.isolated_filesystem():
        write("geometry.in", Si_unit_cell)
        result = runner.invoke(
            clims_initialize_phonopy,
            ["--supercell", "-1", "1", "1", "1", "-1", "1", "1", "1", "-1"],
        )
        assert result.exit_code == 0
        Si_supercell_test = read("displacement-00/geometry.in")
        with open("geomtry_reference.in", "w") as f:
            f.write(Si_supercell_reference)
        compare_geo_files("geomtry_reference.in", "displacement-00/geometry.in")
        with open("displacement-00/aims.out", "w") as f:
            f.write(aims_out)
        result = runner.invoke(clims_post_process_phonopy)
        assert result.exit_code == 0
        with open("total_dos_reference.dat", "w") as f:
            f.write(total_dos_reference)
        compare_data_files("total_dos_reference.dat", "total_dos.dat")


Si_supercell_reference = """#=======================================================
# FHI-aims file: displacement-00/geometry.in
# Created using the Atomic Simulation Environment (ASE)
# Fri Jul 15 22:30:35 2022
#=======================================================
lattice_vector 5.4299999999999997 -0.0000000000000002 -0.0000000000000002
lattice_vector -0.0000000000000002 5.4299999999999997 0.0000000000000002
lattice_vector 0.0000000000000002 0.0000000000000002 5.4299999999999997
atom 0.0100000000000000 -0.0000000000000000 -0.0000000000000000 Si
atom -0.0000000000000000 2.7149999999999999 2.7149999999999994 Si
atom 2.7149999999999999 0.0000000000000000 2.7149999999999999 Si
atom 2.7149999999999999 2.7149999999999999 0.0000000000000000 Si
atom 1.3574999999999999 1.3574999999999999 1.3574999999999999 Si
atom 1.3574999999999997 4.0724999999999998 4.0724999999999998 Si
atom 4.0724999999999998 1.3574999999999999 4.0724999999999998 Si
atom 4.0724999999999998 4.0724999999999998 1.3574999999999999 Si"""

total_dos_reference = """# Tetrahedron method
       -1.2064602962        0.0000000000
       -1.1157587488        0.0000000000
       -1.0250572013        0.0000000000
       -0.9343556538        0.0000000000
       -0.8436541063        0.0000000000
       -0.7529525589        0.0000000000
       -0.6622510114        0.0000000000
       -0.5715494639        0.0000000000
       -0.4808479165        0.0000000000
       -0.3901463690        0.0000000000
       -0.2994448215        0.0000000000
       -0.2087432741        0.0000000000
       -0.1180417266        0.0000000000
       -0.0273401791        0.0000000000
        0.0633613683        0.0000000000
        0.1540629158        0.0000000000
        0.2447644633        0.0000000000
        0.3354660107        0.0010030971
        0.4261675582        0.0037160713
        0.5168691057        0.0060161823
        0.6075706532        0.0085077777
        0.6982722006        0.0113978882
        0.7889737481        0.0149991786
        0.8796752956        0.0189276921
        0.9703768430        0.0232608390
        1.0610783905        0.0279282101
        1.1517799380        0.0334591292
        1.2424814854        0.0388282949
        1.3331830329        0.0449774214
        1.4238845804        0.0517131434
        1.5145861278        0.0580788884
        1.6052876753        0.0663418007
        1.6959892228        0.0740032478
        1.7866907702        0.0824582628
        1.8773923177        0.0922107276
        1.9680938652        0.1012212284
        2.0587954126        0.1122503604
        2.1494969601        0.1234230611
        2.2401985076        0.1353408913
        2.3309000551        0.1489028233
        2.4216016025        0.1620770946
        2.5123031500        0.1775220040
        2.6030046975        0.1939862276
        2.6937062449        0.2111730348
        2.7844077924        0.2319969860
        2.8751093399        0.2523038554
        2.9658108873        0.2753585719
        3.0565124348        0.3019811908
        3.1472139823        0.3298982697
        3.2379155297        0.3612731501
        3.3286170772        0.4006139376
        3.4193186247        0.4408997223
        3.5100201721        0.4920159707
        3.6007217196        0.5511679394
        3.6914232671        0.6234269920
        3.7821248145        0.7182138788
        3.8728263620        0.8470477884
        3.9635279095        1.0597638923
        4.0542294570        1.4439417829
        4.1449310044        1.5025777405
        4.2356325519        1.4763553691
        4.3263340994        1.0757372143
        4.4170356468        0.8540457822
        4.5077371943        0.7221922767
        4.5984387418        0.6427544939
        4.6891402892        0.5804338553
        4.7798418367        0.5388072471
        4.8705433842        0.5034441114
        4.9612449316        0.4844473089
        5.0519464791        0.4663519068
        5.1426480266        0.4645322367
        5.2333495740        0.4861025109
        5.3240511215        0.5270802352
        5.4147526690        0.5532256812
        5.5054542165        0.5839079057
        5.5961557639        0.5494985871
        5.6868573114        0.3384030594
        5.7775588589        0.2047178450
        5.8682604063        0.0497652770
        5.9589619538        0.0517182550
        6.0496635013        0.0539370619
        6.1403650487        0.0562299487
        6.2310665962        0.0585030842
        6.3217681437        0.0607824530
        6.4124696911        0.0633137793
        6.5031712386        0.0659502773
        6.5938727861        0.0686087431
        6.6845743335        0.0712477287
        6.7752758810        0.0741646030
        6.8659774285        0.0772561009
        6.9566789759        0.0803333976
        7.0473805234        0.0834282389
        7.1380820709        0.0869039836
        7.2287836184        0.0904779484
        7.3194851658        0.0940911008
        7.4101867133        0.0977545366
        7.5008882608        0.1019406532
        7.5915898082        0.1061571484
        7.6822913557        0.1104173567
        7.7729929032        0.1150299503
        7.8636944506        0.1199636815
        7.9543959981        0.1250102510
        8.0450975456        0.1301940588
        8.1357990930        0.1361064769
        8.2265006405        0.1421324873
        8.3172021880        0.1483590517
        8.4079037354        0.1553084641
        8.4986052829        0.1627449453
        8.5893068304        0.1704955038
        8.6800083778        0.1792447373
        8.7707099253        0.1887693955
        8.8614114728        0.1991193742
        8.9521130203        0.2108844757
        9.0428145677        0.2245091920
        9.1335161152        0.2404555193
        9.2242176627        0.2600697473
        9.3149192101        0.2862939167
        9.4056207576        0.3262556454
        9.4963223051        0.4435479097
        9.5870238525        0.3811300148
        9.6777254000        0.3363372409
        9.7684269475        0.3071765416
        9.8591284949        0.2870797956
        9.9498300424        0.2708370547
       10.0405315899        0.2564447204
       10.1312331373        0.2446357173
       10.2219346848        0.2336343598
       10.3126362323        0.2229933391
       10.4033377798        0.2129898138
       10.4940393272        0.2031457543
       10.5847408747        0.1929462957
       10.6754424222        0.1826491661
       10.7661439696        0.1726098670
       10.8568455171        0.1605546723
       10.9475470646        0.1506624841
       11.0382486120        0.1379853541
       11.1289501595        0.1225226641
       11.2196517070        0.0968613153
       11.3103532544        0.0817863383
       11.4010548019        0.0675924969
       11.4917563494        0.0738118206
       11.5824578968        0.0888577974
       11.6731594443        0.1124252186
       11.7638609918        0.1550332445
       11.8545625392        0.2269815274
       11.9452640867        0.4109892575
       12.0359656342        0.5366719684
       12.1266671817        0.7110106486
       12.2173687291        0.8868169171
       12.3080702766        0.5878774891
       12.3987718241        0.5057804654
       12.4894733715        0.4432847639
       12.5801749190        0.4066462626
       12.6708764665        0.3744360992
       12.7615780139        0.3546401692
       12.8522795614        0.3337391618
       12.9429811089        0.3193247235
       13.0336826563        0.3045255416
       13.1243842038        0.2918175450
       13.2150857513        0.2804074383
       13.3057872987        0.2688503384
       13.3964888462        0.2593013184
       13.4871903937        0.2487109209
       13.5778919411        0.2402399090
       13.6685934886        0.2304249233
       13.7592950361        0.2225531652
       13.8499965836        0.2131859555
       13.9406981310        0.3632753687
       14.0313996785        0.5638114036
       14.1221012260        0.7687616270
       14.2128027734        1.0448141103
       14.3035043209        1.5465811688
       14.3942058684        2.0664687339
       14.4849074158        2.2307529168
       14.5756089633        2.3512371902
       14.6663105108        2.3054110941
       14.7570120582        2.2432430352
       14.8477136057        2.2061551049
       14.9384151532        2.1938178008
       15.0291167006        1.4375093717
       15.1198182481        1.1413447424
       15.2105197956        0.9106910853
       15.3012213431        0.6852598537
       15.3919228905        0.3499772578
       15.4826244380        0.0000000000
       15.5733259855        0.0000000000
       15.6640275329        0.0000000000
       15.7547290804        0.0000000000
       15.8454306279        0.0000000000
       15.9361321753        0.0000000000
       16.0268337228        0.0000000000
       16.1175352703        0.0000000000
       16.2082368177        0.0000000000
       16.2989383652        0.0000000000
       16.3896399127        0.0000000000
       16.4803414601        0.0000000000
       16.5710430076        0.0000000000
       16.6617445551        0.0000000000
       16.7524461025        0.0000000000
       16.8431476500        0.0000000000
       16.9338491975        0.0000000000"""

==> clims-0.5.0-py3-none-any.whl: test/test_phonons.py <==
from pathlib import Path
from click.testing import CliRunner
from ase.io import write
from ase.build import bulk
from test.file_comparison import compare_geo_files, compare_data_files
from clims.cli.phonons import clims_phonopy

Si_unit_cell = bulk("Si", crystalstructure="diamond", a=5.43)


parent = Path(__file__).parent


def test_phonopy():
    runner = CliRunner()
    with open(parent / "phonons/aims.out") as fd:
        aims_out = fd.read()
    with runner.isolated_filesystem():
        write("geometry.in", Si_unit_cell)
        result = runner.invoke(
            clims_phonopy,
            ["initialize", "--supercell", "-1", "1", "1", "1", "-1", "1", "1", "1", "-1"],
        )
        assert result.exit_code == 0
        with open("geomtry_reference.in", "w") as f:
            f.write(Si_supercell_reference)
        compare_geo_files("geomtry_reference.in", "displacement-00/geometry.in")
        with open("displacement-00/aims.out", "w") as f:
            f.write(aims_out)
        result = runner.invoke(clims_phonopy, "postprocess")
        assert result.exit_code == 0
        with open("total_dos_reference.dat", "w") as f:
            f.write(total_dos_reference)
        compare_data_files("total_dos_reference.dat", "total_dos.dat")


Si_supercell_reference = """#=======================================================
# FHI-aims file: displacement-00/geometry.in
# Created using the Atomic Simulation Environment (ASE)
# Fri Jul 15 22:30:35 2022
#=======================================================
lattice_vector 5.4299999999999997 -0.0000000000000002 -0.0000000000000002
lattice_vector -0.0000000000000002 5.4299999999999997 0.0000000000000002
lattice_vector 0.0000000000000002 0.0000000000000002 5.4299999999999997
atom 0.0100000000000000 -0.0000000000000000 -0.0000000000000000 Si
atom -0.0000000000000000 2.7149999999999999 2.7149999999999994 Si
atom 2.7149999999999999 0.0000000000000000 2.7149999999999999 Si
atom 2.7149999999999999 2.7149999999999999 0.0000000000000000 Si
atom 1.3574999999999999 1.3574999999999999 1.3574999999999999 Si
atom 1.3574999999999997 4.0724999999999998 4.0724999999999998 Si
atom 4.0724999999999998 1.3574999999999999 4.0724999999999998 Si
atom 4.0724999999999998 4.0724999999999998 1.3574999999999999 Si"""

total_dos_reference = """# Tetrahedron method
       -1.2064602962        0.0000000000
       -1.1157587488        0.0000000000
       -1.0250572013        0.0000000000
       -0.9343556538        0.0000000000
       -0.8436541063        0.0000000000
       -0.7529525589        0.0000000000
       -0.6622510114        0.0000000000
       -0.5715494639        0.0000000000
       -0.4808479165        0.0000000000
       -0.3901463690        0.0000000000
       -0.2994448215        0.0000000000
       -0.2087432741        0.0000000000
       -0.1180417266        0.0000000000
       -0.0273401791        0.0000000000
        0.0633613683        0.0000000000
        0.1540629158        0.0000000000
        0.2447644633        0.0000000000
        0.3354660107        0.0010030971
        0.4261675582        0.0037160713
        0.5168691057        0.0060161823
        0.6075706532        0.0085077777
        0.6982722006        0.0113978882
        0.7889737481        0.0149991786
        0.8796752956        0.0189276921
        0.9703768430        0.0232608390
        1.0610783905        0.0279282101
        1.1517799380        0.0334591292
        1.2424814854        0.0388282949
        1.3331830329        0.0449774214
        1.4238845804        0.0517131434
        1.5145861278        0.0580788884
        1.6052876753        0.0663418007
        1.6959892228        0.0740032478
        1.7866907702        0.0824582628
        1.8773923177        0.0922107276
        1.9680938652        0.1012212284
        2.0587954126        0.1122503604
        2.1494969601        0.1234230611
        2.2401985076        0.1353408913
        2.3309000551        0.1489028233
        2.4216016025        0.1620770946
        2.5123031500        0.1775220040
        2.6030046975        0.1939862276
        2.6937062449        0.2111730348
        2.7844077924        0.2319969860
        2.8751093399        0.2523038554
        2.9658108873        0.2753585719
        3.0565124348        0.3019811908
        3.1472139823        0.3298982697
        3.2379155297        0.3612731501
        3.3286170772        0.4006139376
        3.4193186247        0.4408997223
        3.5100201721        0.4920159707
        3.6007217196        0.5511679394
        3.6914232671        0.6234269920
        3.7821248145        0.7182138788
        3.8728263620        0.8470477884
        3.9635279095        1.0597638923
        4.0542294570        1.4439417829
        4.1449310044        1.5025777405
        4.2356325519        1.4763553691
        4.3263340994        1.0757372143
        4.4170356468        0.8540457822
        4.5077371943        0.7221922767
        4.5984387418        0.6427544939
        4.6891402892        0.5804338553
        4.7798418367        0.5388072471
        4.8705433842        0.5034441114
        4.9612449316        0.4844473089
        5.0519464791        0.4663519068
        5.1426480266        0.4645322367
        5.2333495740        0.4861025109
        5.3240511215        0.5270802352
        5.4147526690        0.5532256812
        5.5054542165        0.5839079057
        5.5961557639        0.5494985871
        5.6868573114        0.3384030594
        5.7775588589        0.2047178450
        5.8682604063        0.0497652770
        5.9589619538        0.0517182550
        6.0496635013        0.0539370619
        6.1403650487        0.0562299487
        6.2310665962        0.0585030842
        6.3217681437        0.0607824530
        6.4124696911        0.0633137793
        6.5031712386        0.0659502773
        6.5938727861        0.0686087431
        6.6845743335        0.0712477287
        6.7752758810        0.0741646030
        6.8659774285        0.0772561009
        6.9566789759        0.0803333976
        7.0473805234        0.0834282389
        7.1380820709        0.0869039836
        7.2287836184        0.0904779484
        7.3194851658        0.0940911008
        7.4101867133        0.0977545366
        7.5008882608        0.1019406532
        7.5915898082        0.1061571484
        7.6822913557        0.1104173567
        7.7729929032        0.1150299503
        7.8636944506        0.1199636815
        7.9543959981        0.1250102510
        8.0450975456        0.1301940588
        8.1357990930        0.1361064769
        8.2265006405        0.1421324873
        8.3172021880        0.1483590517
        8.4079037354        0.1553084641
        8.4986052829        0.1627449453
        8.5893068304        0.1704955038
        8.6800083778        0.1792447373
        8.7707099253        0.1887693955
        8.8614114728        0.1991193742
        8.9521130203        0.2108844757
        9.0428145677        0.2245091920
        9.1335161152        0.2404555193
        9.2242176627        0.2600697473
        9.3149192101        0.2862939167
        9.4056207576        0.3262556454
        9.4963223051        0.4435479097
        9.5870238525        0.3811300148
        9.6777254000        0.3363372409
        9.7684269475        0.3071765416
        9.8591284949        0.2870797956
        9.9498300424        0.2708370547
       10.0405315899        0.2564447204
       10.1312331373        0.2446357173
       10.2219346848        0.2336343598
       10.3126362323        0.2229933391
       10.4033377798        0.2129898138
       10.4940393272        0.2031457543
       10.5847408747        0.1929462957
       10.6754424222        0.1826491661
       10.7661439696        0.1726098670
       10.8568455171        0.1605546723
       10.9475470646        0.1506624841
       11.0382486120        0.1379853541
       11.1289501595        0.1225226641
       11.2196517070        0.0968613153
       11.3103532544        0.0817863383
       11.4010548019        0.0675924969
       11.4917563494        0.0738118206
       11.5824578968        0.0888577974
       11.6731594443        0.1124252186
       11.7638609918        0.1550332445
       11.8545625392        0.2269815274
       11.9452640867        0.4109892575
       12.0359656342        0.5366719684
       12.1266671817        0.7110106486
       12.2173687291        0.8868169171
       12.3080702766        0.5878774891
       12.3987718241        0.5057804654
       12.4894733715        0.4432847639
       12.5801749190        0.4066462626
       12.6708764665        0.3744360992
       12.7615780139        0.3546401692
       12.8522795614        0.3337391618
       12.9429811089        0.3193247235
       13.0336826563        0.3045255416
       13.1243842038        0.2918175450
       13.2150857513        0.2804074383
       13.3057872987        0.2688503384
       13.3964888462        0.2593013184
       13.4871903937        0.2487109209
       13.5778919411        0.2402399090
       13.6685934886        0.2304249233
       13.7592950361        0.2225531652
       13.8499965836        0.2131859555
       13.9406981310        0.3632753687
       14.0313996785        0.5638114036
       14.1221012260        0.7687616270
       14.2128027734        1.0448141103
       14.3035043209        1.5465811688
       14.3942058684        2.0664687339
       14.4849074158        2.2307529168
       14.5756089633        2.3512371902
       14.6663105108        2.3054110941
       14.7570120582        2.2432430352
       14.8477136057        2.2061551049
       14.9384151532        2.1938178008
       15.0291167006        1.4375093717
       15.1198182481        1.1413447424
       15.2105197956        0.9106910853
       15.3012213431        0.6852598537
       15.3919228905        0.3499772578
       15.4826244380        0.0000000000
       15.5733259855        0.0000000000
       15.6640275329        0.0000000000
       15.7547290804        0.0000000000
       15.8454306279        0.0000000000
       15.9361321753        0.0000000000
       16.0268337228        0.0000000000
       16.1175352703        0.0000000000
       16.2082368177        0.0000000000
       16.2989383652        0.0000000000
       16.3896399127        0.0000000000
       16.4803414601        0.0000000000
       16.5710430076        0.0000000000
       16.6617445551        0.0000000000
       16.7524461025        0.0000000000
       16.8431476500        0.0000000000
       16.9338491975        0.0000000000"""
